@@ -418,8 +418,8 @@ tfVisPlot <- function (x, tf = tframe(x), start = tfstart(tf), end = tfend(tf),
     nm <- seriesNames(x)
     names(seriesData) <- c("date", nm)
     
-    if (!require("googleVis")) stop("tfVisPlot requires googleVis")
-    else  plot(gvisLineChart(seriesData, xvar="date", yvar=nm,
+    if (!requireNamespace("googleVis")) stop("tfVisPlot requires googleVis")
+    else  plot(googleVis::gvisLineChart(seriesData, xvar="date", yvar=nm,
          options=options, ...))
     cat("look for chart in web browser.\n")
     invisible(x)
